from math import log, ceil
"""Constants used in this package."""

HIRAGANA_SET = 'あいうえおかきくけこさしすせそたちつてとなにぬねのはひふへほまみむめもやゆよらりるれろわゐゑをんぁぃぅぇぉゃゅょっーがぎぐげござじずぜぞだぢづでどばびぶべぼぱぴぷぺぽ'
KATAKANA_SET = 'アイウエオカキクケコサシスセソタチツテトナニヌネノハヒフヘホマミムメモヤユヨラリルレロワヰヱヲンァィゥェォャュョッーガギグゲゴザジズゼゾダチヅデドバビブベボパピプペポヴ'

unit = [
    ['ゼロ', '零'],
    ['いち', '一'],
    ['に', '二'],
    ['さん', '三'],
    ['よん', '四'],
    ['ご', '五'],
    ['ろく', '六'],
    ['なな', '七'],
    ['はち', '八'],
    ['きゅう', '九'],
    ['じゅう', '十']
    ]
tens = {
    1: ['じゅう', '十'],
    2: ['ひゃく', '百'],
    3: ['せん', '千'],
    4: ['まん', '万'],
    8: ['おく', '億'],
    12: ['ちょう', '兆'],
    16: ['けい', '京'],
    20: ['がい', '垓']
}
specials = {
    10: ['じゅう', '十'],
    100: ['ひゃく', '百'],
    300: ['さんびゃく', '三百'],
    600: ['ろっぴゃく', '六百'],
    800: ['はっぴゃく', '八百'],
    1000: ['せん', '千'],
    3000: ['さんぜん', '三千'],
    8000: ['はっせん', '八千'],
    10**12: ['いっちょう', '一兆'],
    8*10**12: ['はっちょう', '八兆'],
    10**13: ['じゅっちょう', '十兆'],
    10**16: ['いっけい', '一京'],
    6*10**16: ['ろっけい', '六京'],
    8*10**16: ['はっけい', '八京'],
    10**17: ['じゅっけい', '十京'],
    10**18: ['ひゃっけい', '百京']
}
minus = 'マイナス'
period = ['てん', '点']
LIMIT = ceil(max(tens.keys())) + 3
MAX_VAL = 10**(LIMIT + 1) - 1
SEPARATOR = '.'

kana = {
    'ka': ['か', 'カ'],
    'ki': ['き', 'キ'],
    'ku': ['く', 'ク'],
    'ke': ['け', 'ケ'],
    'ko': ['こ', 'コ'],
    'sa': ['さ', 'サ'],
    'su': ['す', 'ス'],
    'se': ['せ', 'セ'],
    'so': ['そ', 'ソ'],
    'ta': ['た', 'タ'],
    'te': ['て', 'テ'],
    'to': ['と', 'ト'],
    'na': ['な', 'ナ'],
    'ni': ['に', 'ニ'],
    'nu': ['ぬ', 'ヌ'],
    'ne': ['ね', 'ネ'],
    'no': ['の', 'ノ'],
    'ha': ['は', 'ハ'],
    'hi': ['ひ', 'ヒ'],
    'fu': ['ふ', 'フ'],
    'he': ['へ', 'ヘ'],
    'ho': ['ほ', 'ホ'],
    'ma': ['ま', 'マ'],
    'mi': ['み', 'ミ'],
    'mu': ['む', 'ム'],
    'me': ['め', 'メ'],
    'mo': ['も', 'モ'],
    'ya': ['や', 'ヤ'],
    'yu': ['ゆ', 'ユ'],
    'yo': ['よ', 'ヨ'],
    'ra': ['ら', 'ラ'],
    'ri': ['り', 'リ'],
    'ru': ['る', 'ル'],
    're': ['れ', 'レ'],
    'ro': ['ろ', 'ロ'],
    'wa': ['わ', 'ワ'],
    'wo': ['を', 'ヲ'],
    'ga': ['が', 'ガ'],
    'gi': ['ぎ', 'ギ'],
    'gu': ['ぐ', 'グ'],
    'ge': ['げ', 'ゲ'],
    'go': ['ご', 'ゴ'],
    'za': ['ざ', 'ザ'],
    'ji': ['じ', 'ジ'],
    'zi': ['じ', 'ジ'],
    'zu': ['ず', 'ズ'],
    'ze': ['ぜ', 'ゼ'],
    'zo': ['ぞ', 'ゾ'],
    'da': ['だ', 'ダ'],
    'di': ['ぢ', 'ヂ'],
    'du': ['づ', 'ヅ'],
    'de': ['で', 'デ'],
    'do': ['ど', 'ド'],
    'ba': ['ば', 'バ'],
    'bi': ['び', 'ビ'],
    'bu': ['ぶ', 'ブ'],
    'be': ['べ', 'ベ'],
    'bo': ['ぼ', 'ボ'],
    'pa': ['ぱ', 'パ'],
    'pi': ['ぴ', 'ピ'],
    'pu': ['ぷ', 'プ'],
    'pe': ['ぺ', 'ペ'],
    'po': ['ぽ', 'ポ']
}
kana2 = {
    'shi': ['し', 'シ'],
    'chi': ['ち', 'チ'],
    'tsu': ['つ', 'ツ']
}
small_kana = {
    'xtsu': ['っ', 'ッ'],
    'xya': ['ゃ', 'ャ'],
    'xyu': ['ゅ', 'ュ'],
    'xyo': ['ょ', 'ョ']
}
vowel_kana = {
    'a': ['あ', 'ア'],
    'i': ['い', 'イ'],
    'u': ['う', 'ウ'],
    'e': ['え', 'エ'],
    'o': ['お', 'オ']
}
kana_n = ['ん', 'ン']
double_consonants = ['kk', 'ss', 'tt', 'hh', 'mm', 'rr', 'yy', 'ww', 'gg', 'zz', 'jj', 'dd', 'bb', 'pp']
small_y = {
    'ky': 'kixy',
    'sha': 'shixya',
    'shu': 'shixyu',
    'sho': 'shixyo',
    'cha': 'chixya',
    'chu': 'chixyu',
    'cho': 'chixyo',
    'ny': 'nixy',
    'hy': 'hixy',
    'my': 'mixy',
    'ry': 'rixy',
    'ja': 'jixya',
    'ju': 'jixyu',
    'jo': 'jixyo',
    'jy': 'jixy',
    'gy': 'gixy',
    'dy': 'dixy',
    'by': 'bixy',
    'py': 'pixy'
}
katakana_long_vowel = 'ー'
